@@ -10,7 +10,6 @@ import (
 	"net/http"
 	"net/url"
 	"os"
-	"reflect"
 	"strconv"
 	"strings"
 	"time"
@@ -554,39 +553,31 @@ func Init(ctx context.Context, cfg *Config) (*Proxy, error) {
 // ExtractRequestData takes an interface with request data from a Stripe event payload
 // and properly parses it into a StripeRequest struct before returning it
 func ExtractRequestData(data interface{}) (StripeRequest, error) {
-	var req StripeRequest
+	switch v := data.(type) {
+	// versions after 2017-05-25 represent request_data as an object
+	case map[string]interface{}:
+		req := StripeRequest{}
 
-	reqDataValue := reflect.ValueOf(data)
-	// here we check the type of the RequestData as it could be either a string or a map
-	// this depends on which API version is in use when listening to events
-	// versions including and prior to 2017-05-25 present the request field as a string
-	switch reqDataValue.Kind() {
-	case reflect.String:
-		req = StripeRequest{
-			ID:             data.(string),
-			IdempotencyKey: "",
-		}
-	case reflect.Map:
-		reqDataMap := reqDataValue.Interface().(map[string]interface{})
-
-		var id = ""
-		if rawID, ok := reqDataMap["id"]; ok && rawID != nil {
-			id = rawID.(string)
+		if rawID, ok := v["id"]; ok && rawID != nil {
+			req.ID = rawID.(string)
 		}
 
-		var idempotencyKey = ""
-		if rawKey, ok := reqDataMap["idempotency_key"]; ok && rawKey != nil {
-			idempotencyKey = rawKey.(string)
+		if rawKey, ok := v["idempotency_key"]; ok && rawKey != nil {
+			req.IdempotencyKey = rawKey.(string)
 		}
 
-		req = StripeRequest{
-			ID:             id,
-			IdempotencyKey: idempotencyKey,
-		}
-	default:
-		return StripeRequest{}, errors.New("Received malformed event from Stripe")
+		return req, nil
+
+	// versions including and prior to 2017-05-25 present the request field as
+	// an optional string, which is nil when the event was triggered by a
+	// non-user-visible request (e.g., 3D Secure callbacks).
+	case string:
+		return StripeRequest{ID: v}, nil
+	case nil:
+		return StripeRequest{}, nil
 	}
-	return req, nil
+
+	return StripeRequest{}, errors.New("Received malformed event from Stripe")
 }
 
 //
